allows you to add rules and rulesets into larger rulesets. This
can be useful if you want to create a ruleset for a dataset out of checks
for other datasets.
Usage
datavarifyr_plus(a, b)# S3 method for class 'ruleset'a+b# S3 method for class 'rule'a+b