describe: Describes a dataset

View source: R/describe.R

describeR Documentation

Describes a dataset

Description

Note that the current version is in the beta stadium at best, that means the R-native formats (data.frame, dplyr/tibble, or data.table) are a lot faster than arrow or SQL-based datasets.

Usage

describe(x, skip_ones = TRUE, digits = 4, top_n = 3, fast = FALSE)

Arguments

x

a dataset, either a data.frame, dplyr::tibble, data.table::data.table, arrow::arrow_table, arrow::open_dataset, or dplyr::tbl (SQL connection)

skip_ones

logical, whether values that occur exactly once should be omitted from most_frequent

digits

integer, number of digits to round numeric values in most_frequent

top_n

integer, number of most frequent values to include in most_frequent; set to 0 to skip the most_frequent computation

fast

logical, when TRUE skip expensive fields (n_distinct, median) by returning NA for them

Details

Numeric values in most_frequent are rounded to digits (default: 4). If a variable has at most 1 distinct value, most_frequent is left empty. By default, values with count 1 are omitted from most_frequent.

Value

a data.frame, dplyr::tibble, or data.table::data.table containing a summary of the dataset given

See Also

Similar to skimr::skim(), summarytools::dfSummary(), and gtExtras::gt_plt_summary()

Examples

describe(mtcars)

dataverifyr documentation built on April 11, 2026, 1:06 a.m.