| describe | R Documentation |
Note that the current version is in the beta stadium at best, that means the R-native formats (data.frame, dplyr/tibble, or data.table) are a lot faster than arrow or SQL-based datasets.
describe(x, skip_ones = TRUE, digits = 4, top_n = 3, fast = FALSE)
x |
a dataset, either a |
skip_ones |
logical, whether values that occur exactly once should be omitted
from |
digits |
integer, number of digits to round numeric values in |
top_n |
integer, number of most frequent values to include in |
fast |
logical, when |
Numeric values in most_frequent are rounded to digits (default: 4).
If a variable has at most 1 distinct value, most_frequent is left empty.
By default, values with count 1 are omitted from most_frequent.
a data.frame, dplyr::tibble, or data.table::data.table containing
a summary of the dataset given
Similar to skimr::skim(), summarytools::dfSummary(), and gtExtras::gt_plt_summary()
describe(mtcars)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.